@@ -11,7 +11,7 @@ Business::Mondo - Perl library for interacting with the Mondo API
 
 =head1 VERSION
 
-0.02
+0.03
 
 =head1 DESCRIPTION
 
@@ -53,6 +53,8 @@ will, for the most part, return new instances of objects.
 
     foreach my $Account ( @accounts ) {
 
+        my @transactions = $Account->transactions;
+
         $Account->add_feed_item(
             params => {
                 title     => 'My Feed Item',
@@ -61,7 +63,7 @@ will, for the most part, return new instances of objects.
         );
 
         # balance information
-        my $Balance = $mondo->balance( account_id => $account_id );
+        my $Balance = $Account->balance;
 
         # webhooks
         my @webhooks = $Account->webhooks;
@@ -73,7 +75,7 @@ will, for the most part, return new instances of objects.
         $Webhook->delete
     }
 
-    # attachements
+    # attachments
     my $Attachment = $mondo->upload_attachment(
         file_name => 'foo.png',
         file_type => 'image/png',
@@ -89,9 +91,7 @@ will, for the most part, return new instances of objects.
 
 Any problems or errors will result in a Business::Mondo::Exception
 object being thrown, so you should wrap any calls to the library in the
-appropriate error catching code (TryCatch in the below example):
-
-    use TryCatch;
+appropriate error catching code (ideally a module from CPAN):
 
     try {
         ...
@@ -122,6 +122,9 @@ stack trace in the event of exceptions:
 
 =cut
 
+use strict;
+use warnings;
+
 use Moo;
 with 'Business::Mondo::Version';
 
@@ -170,7 +173,8 @@ has client => (
     default  => sub {
         my ( $self ) = @_;
 
-        return Business::Mondo::Client->new(
+        # fix any load order issues with Resources requiring a Client
+        $Business::Mondo::Resource::client = Business::Mondo::Client->new(
             token   => $self->token,
             api_url => $self->api_url,
         );
@@ -224,8 +228,6 @@ Get an account balance Returns a L<Business::Mondo::Balance> object.
 sub balance {
     my ( $self,%params ) = @_;
 
-    # transactions requires account_id, whereas transaction doesn't
-    # the Mondo API is a little inconsistent at this point...
     $params{account_id} || Business::Mondo::Exception->throw({
         message => "balance requires params: account_id",
     });
