@@ -10,6 +10,9 @@ A class for a Mondo transaction, extends L<Business::Mondo::Resource>
 
 =cut
 
+use strict;
+use warnings;
+
 use Moo;
 extends 'Business::Mondo::Resource';
 with 'Business::Mondo::Utils';
@@ -17,6 +20,7 @@ with 'Business::Mondo::Currency';
 
 use Types::Standard qw/ :all /;
 use Business::Mondo::Merchant;
+use Business::Mondo::Attachment;
 use DateTime::Format::DateParse;
 
 =head1 ATTRIBUTES
@@ -34,6 +38,7 @@ The Transaction class has the following attributes (with their type).
     currency (Data::Currency)
     created (DateTime)
     settled (DateTime)
+    attachments (ArrayRef[Business::Mondo::Attachment])
 
 Note that if a HashRef or Str is passed to ->merchant it will be coerced
 into a Business::Mondo::Merchant object. When a Str is passed to ->currency
@@ -87,6 +92,27 @@ has merchant => (
     },
 );
 
+has attachments => (
+    is      => 'ro',
+    isa     => Maybe[ArrayRef[InstanceOf['Business::Mondo::Attachment']]],
+    coerce  => sub {
+        my ( $args ) = @_;
+
+        return undef if ! defined $args;
+
+        my @attachments;
+
+        foreach my $attachment ( @{ $args } ) {
+            push( @attachments,Business::Mondo::Attachment->new(
+                client => $Business::Mondo::Resource::client,
+                %{ $attachment },
+            ) );
+        }
+
+        return [ @attachments ];
+    },
+);
+
 has [ qw/ created settled / ] => (
     is      => 'ro',
     isa     => Maybe[InstanceOf['DateTime']],
