@@ -10,9 +10,12 @@ A role for a Mondo version information.
 
 =cut
 
+use strict;
+use warnings;
+
 use Moo::Role;
 
-$Business::Mondo::VERSION     = '0.02';
+$Business::Mondo::VERSION     = '0.03';
 $Business::Mondo::API_VERSION = 'v1';
 $Business::Mondo::API_URL     = 'https://api.getmondo.co.uk';
 
